@@ -738,10 +738,11 @@ g_resolver_lookup_service_cb (GResolver    *resolver,
     }
   else if (!data->base_domain_fallback)
     {
+      g_autofree char *domain_lowercase = g_utf8_casefold (data->domain, -1);
       const char *base_domain = NULL;
 
-      base_domain = soup_tld_get_base_domain (data->domain, NULL);
-      if (base_domain == NULL || g_strcmp0 (data->domain, base_domain) == 0)
+      base_domain = soup_tld_get_base_domain (domain_lowercase, NULL);
+      if (base_domain == NULL || g_strcmp0 (domain_lowercase, base_domain) == 0)
         {
           g_task_return_error (task, g_steal_pointer (&error));
           return;
@@ -1174,10 +1175,21 @@ dav_client_discover_iterate (GTask *task)
     {
       if (!discover->uri_fallback)
         {
+          g_autofree char *nc_uri = NULL;
+
+          /* Start with Nextcloud, everyone's favourite sort of compliant DAV server, since
+           * we can return early if we recognize the path.
+           */
+          nc_uri = g_uri_resolve_relative (discover->uri, "remote.php/dav", G_URI_FLAGS_NONE, NULL);
+          g_queue_push_tail (&discover->candidates,
+                             goa_dav_config_new (GOA_SERVICE_TYPE_WEBDAV, nc_uri, NULL));
+
           g_queue_push_tail (&discover->candidates,
                              goa_dav_config_new (GOA_SERVICE_TYPE_CALDAV, discover->uri, NULL));
           g_queue_push_tail (&discover->candidates,
                              goa_dav_config_new (GOA_SERVICE_TYPE_CARDDAV, discover->uri, NULL));
+          g_queue_push_tail (&discover->candidates,
+                             goa_dav_config_new (GOA_SERVICE_TYPE_WEBDAV, discover->uri, NULL));
 
           discover->uri_fallback = TRUE;
           dav_client_discover_iterate (task);
@@ -1210,12 +1222,13 @@ static gboolean
 dav_client_discover_preconfig (DiscoverData *discover,
                                GUri         *uri)
 {
-  const char *host = NULL;
+  g_autofree char *host = NULL;
   const char *base_domain = NULL;
 
   g_assert (discover != NULL);
 
-  host = g_uri_get_host (uri);
+  if (g_uri_get_host (uri))
+    host = g_utf8_casefold (g_uri_get_host (uri), -1);
   if (host != NULL)
     base_domain = soup_tld_get_base_domain (host, NULL);
 
@@ -1350,9 +1363,6 @@ goa_dav_client_discover (GoaDavClient        *self,
                                  (GAsyncReadyCallback) dav_client_discover_lookup_cb,
                                  g_object_ref (task));
     }
-
-  g_queue_push_tail (&discover->candidates,
-                     goa_dav_config_new (GOA_SERVICE_TYPE_WEBDAV, discover->uri, NULL));
 }
 
 /**
